==> u++_5.0.1.orig.tar.gz: u++-5.0.1/src/scheduler/uPIHeap.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Ashif S. Harji 2000
// 
// uPIHeap.h -- 
// 
// Author           : Ashif S. Harji
// Created On       : Fri Jan 14 17:53:22 2000
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Jun 28 16:59:07 2001
// Update Count     : 14
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_PIHEAP_H__
#define __U_PIHEAP_H__

#pragma __U_NOT_USER_CODE__


//#include <uDebug.h>

#include <uHeap.h>


#define __U_MAX_NUMBER_PRIORITIES__ 32


class uPIHeap : public uBasePIQ {
    struct uHeapBaseSeq {
	int index;
	int count;
	int queueNum;
	//uBaseTaskSeq queue;
    };

    uHeapBaseSeq uObjects[ __U_MAX_NUMBER_PRIORITIES__ ]; 
    uHeap<int, uHeapBaseSeq *, __U_MAX_NUMBER_PRIORITIES__> heap;
    uSpinLock lock;
    
    static int compare(int k1, int k2);
    static void exchange( uHeapable<int, uHeapBaseSeq *> &x, uHeapable<int, uHeapBaseSeq *> &y );
  public:
    uPIHeap();
    virtual bool uEmpty() const;
    virtual int uHead();
    virtual int uGetHighestPriority();
    virtual void uAdd( int priority, int queueNum );
    virtual int uDrop();
    virtual void uRemove( int priority, int queueNum ); 
}; // PIHeap


#endif // __U_PIHEAP_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //

==> u++_5.3.0.orig.tar.gz: u++-5.3.0/src/scheduler/uPIHeap.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
// 
// uPIHeap.h -- 
// 
// Author           : Ashif S. Harji
// Created On       : Fri Jan 14 17:53:22 2000
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Oct 10 10:29:05 2005
// Update Count     : 20
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_PIHEAP_H__
#define __U_PIHEAP_H__

#pragma __U_NOT_USER_CODE__


//#include <uDebug.h>

#include <uHeap.h>


#define __U_MAX_NUMBER_PRIORITIES__ 32


class uPIHeap : public uBasePIQ {
    struct uHeapBaseSeq {
	int index;
	int count;
	int queueNum;
	//uBaseTaskSeq queue;
    };

    uHeapBaseSeq uObjects[ __U_MAX_NUMBER_PRIORITIES__ ]; 
    uHeap<int, uHeapBaseSeq *, __U_MAX_NUMBER_PRIORITIES__> heap;
    uSpinLock lock;
    
    static int compare(int k1, int k2);
    static void exchange( uHeapable<int, uHeapBaseSeq *> &x, uHeapable<int, uHeapBaseSeq *> &y );
  public:
    uPIHeap();
    virtual bool empty() const;
    virtual int head() const;
    virtual int uGetHighestPriority();
    virtual void add( int priority, int queueNum );
    virtual int drop();
    virtual void remove( int priority, int queueNum ); 
}; // PIHeap


#endif // __U_PIHEAP_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
